Greetings from the Open Computing Facility,

Your OCF account, {{request.user_name}} has been rejected for the following reason:

{{reason}}

For information about account eligibility, see:

https://www.ocf.berkeley.edu/docs/membership/

If you have any other questions or problems, feel free to contact us by
replying to this message.

{{mail_signature}}
